--------------------------------------------------
---  Copyright 20008-2011, HDRsoft - www.hdrsoft.com   
--------------------------------------------------

local LrApplication = import 'LrApplication'
local LrBinding = import 'LrBinding'
local LrView = import 'LrView'
local LrDialogs = import 'LrDialogs'
local LrFunctionContext = import 'LrFunctionContext'
local LrErrors = import 'LrErrors'
local LrFileUtils = import 'LrFileUtils'
local LrPathUtils = import 'LrPathUtils'
local LrLogger = import 'LrLogger'
local prefs = import 'LrPrefs'.prefsForPlugin() 

local myLogger = LrLogger('PhotomatixLogger')
myLogger:enable("print") 

local cntPhotos=0
local folderPath=''

PhotomatixSettings = {}

function PhotomatixSettings.outputToLog(message)
	myLogger:trace(message)
end


function PhotomatixSettings.debutCommun(fic1, fic2, minSeuilLen)
	local resStr=''
	local i=1
	local lenFicMin=#fic1
	if #fic2<lenFicMin then 
		lenFicMin=#fic2
	end
	while (i<=lenFicMin) do
		if string.sub(fic1, i, i) ~= string.sub(fic2, i, i) then
			break
		end
		i=i+1
	end	
	if (i>minSeuilLen) then
		resStr=string.sub(fic1, 1, i-1)
	end
	return resStr
end

function PhotomatixSettings.firstFileName( )
	local firstFileName=''
	local activeCatalog = LrApplication.activeCatalog()
	activeCatalog:withReadAccessDo( function()
		local photos = activeCatalog.targetPhotos	
		firstFileName=LrPathUtils.leafName(LrPathUtils.removeExtension(photos[1].path)) 
	end )
	return firstFileName
end


function PhotomatixSettings.defaultFileName( )
	local combinedFileName=''
	
	if prefs.LrVersion<2 then
		return combinedFileName
	end
	local activeCatalog = LrApplication.activeCatalog()
	activeCatalog:withReadAccessDo( function()
		local photos = activeCatalog.targetPhotos	
		cntPhotos=#photos
		folderPath=LrPathUtils.parent(photos[1].path)

		if cntPhotos==1 then
			combinedFileName=string.format('%s_tonemapped', LrPathUtils.leafName(LrPathUtils.removeExtension(photos[1].path)))
		else

		local iPhoto=1
		local commonStr=''
		local firstFileName=LrPathUtils.leafName(LrPathUtils.removeExtension(photos[1].path))
		local maxLen=0
		for iPhoto=2, cntPhotos, 1 do		
			local curFileName=LrPathUtils.leafName(LrPathUtils.removeExtension(photos[iPhoto].path))
			if (iPhoto==2) then
				commonStr=PhotomatixSettings.debutCommun(firstFileName, curFileName, 2) 
			else 
				if #commonStr>1 then
					commonStr=PhotomatixSettings.debutCommun(commonStr, curFileName, 2) 
				end
			end	
			if #curFileName>maxLen then 
				maxLen=#curFileName
			end
		end

		if #commonStr>1 then
			if ((maxLen - #commonStr) <= 8) then
				combinedFileName=firstFileName
				local cntSameName=0
				for iPhoto=2, cntPhotos, 1 do		
					local curFileName=LrPathUtils.leafName(LrPathUtils.removeExtension(photos[iPhoto].path))
					local differingPart=string.sub(curFileName, #commonStr+1)
					if #differingPart>0 then
						combinedFileName=string.format('%s_%s', combinedFileName, differingPart)  
					else
						cntSameName=cntSameName+1
					end		
				end
				if (cntSameName==(cntPhotos-1)) then
					combinedFileName=string.format('%sx%d',firstFileName,cntPhotos)
				end
			end
		end	

		if ((#combinedFileName<2) or (cntPhotos > 7)) then
			combinedFileName=string.format('%sAnd%dmore', firstFileName, cntPhotos-1)
		end
		
		end -- fin if cntPhotos==1 
	end )

	return combinedFileName
end


function PhotomatixSettings.getOptions( )

	local isLr2=false
	local titleBox2="Handling of HDR Processed Image (requires Lightroom 2)"

	if prefs.LrVersion==nil then
		LrDialogs.message("Plugin did not start correctly","Please check whether you invoked the plugin by choosing 'File > Plug-in Extras'","info")
		return
	end

	if prefs.LrVersion>1 then
		isLr2=true
		titleBox2=LOC "$$$/Photomatix/Settings/BoxTitle=Handling of HDR Processed Image"
	end

	LrFunctionContext.callWithContext( 'photomatixSettings', function( context )

	local f = LrView.osFactory() 
	local props = LrBinding.makePropertyTable( context ) 
	props.processType = 'ToneMap'
	props.chkAlign=true
	props.alignType='1'
	props.chkCrop=true
	props.chkPerspective=true
	props.chkReduceCA=false
	props.chkReduceNoise=false
	props.nrWhat='0'
	props.chkGhosting=false
	props.ghostingType='1'
	props.ghostingDetection='normal'
	props.chkShowHDR=false
	props.outputFormat='tif16'
	props.stackWith=false
	props.waitForPhotomatix=false

	props.chkAddSuffix=false
	props.fileNameSuffix=''
	props.outputFileNameOption='0'
	props.combinedFileName=PhotomatixSettings.defaultFileName()  
	props.firstFileName=PhotomatixSettings.firstFileName()  

	if cntPhotos==1 then
		props.outputName=props.combinedFileName
	end

	if ((prefs.processType~=nil) and (prefs.processType~='none')) then
		props.processType=prefs.processType
	end
	if (prefs.chkAlign~=nil) then
		props.chkAlign=prefs.chkAlign
	end
	if (prefs.chkCrop~=nil) then
		props.chkCrop=prefs.chkCrop
	end
	if (prefs.alignType~=nil) then
		if ((prefs.alignType=='1')or(prefs.alignType=='2')) then
			props.alignType=prefs.alignType
		end
	end
	if (prefs.chkPerspective~=nil) then
		props.chkPerspective=prefs.chkCrop
	end
	if (prefs.ghostingType~=nil) then
	        if ((prefs.ghostingType=='1') or (prefs.ghostingType=='2')) then
		        props.ghostingType=prefs.ghostingType
		end
	end
	if (prefs.chkPerspective~=nil) then
		props.chkPerspective=prefs.chkPerspective
	end
	if ((prefs.chkGhosting)and((prefs.ghostingType=='1')or(prefs.ghostingType=='2'))) then
		props.chkGhosting=prefs.chkGhosting
	end
	if (prefs.ghostingDetection~=nil) then
		props.ghostingDetection=prefs.ghostingDetection
	end
	if (prefs.chkReduceNoise) then
		props.chkReduceNoise=prefs.chkReduceNoise
	end
	if (prefs.nrWhat~=nil) then
		props.nrWhat=prefs.nrWhat
	end
	if (prefs.chkReduceCA) then
		props.chkReduceCA=prefs.chkReduceCA
	end
	if (prefs.chkShowHDR) then
		props.chkShowHDR=prefs.chkShowHDR
	end
	if (prefs.outputFormat~=nil) then
		props.outputFormat=prefs.outputFormat
	end
	if (prefs.waitForPhotomatix) then
		props.waitForPhotomatix=prefs.waitForPhotomatix
	end
	if (prefs.stackWith) then
		props.stackWith=prefs.stackWith
	end
	
	if (prefs.outputFileNameOption~=nil) then
		props.outputFileNameOption=prefs.outputFileNameOption
	end
	if (prefs.chkAddSuffix) then
		props.chkAddSuffix=prefs.chkAddSuffix
	end
	if (prefs.fileNameSuffix~=nil) then
		props.fileNameSuffix=prefs.fileNameSuffix
	end

	local updateFileNameFunction = function() 
		if props.outputFileNameOption == '10' then
			return
		end
		local curFileName=props.combinedFileName
		if props.outputFileNameOption == '1' then
			curFileName=props.firstFileName
		end
		outputFileNameEditField.value=string.format('%s%s', curFileName, props.fileNameSuffix)
	end
	props:addObserver( "fileNameSuffix", updateFileNameFunction )
	
	local LeftMarginSavePanel=135
	
	local outputFileNameEditField=f:edit_field { 
		width_in_chars = 24, 
		value = LrView.bind {
			keys = { 'outputFileNameOption', 'chkAddSuffix', 'fileNameSuffix' },
				operation = function( binder, values, fromTable )
					local curFileName=''
					if fromTable then
						if values.outputFileNameOption == '0' then
							curFileName=props.combinedFileName
						end
						if values.outputFileNameOption == '1' then
							curFileName=props.firstFileName
						end
						if values.outputFileNameOption == '10' then
							curFileName=''
						else
							if values.chkAddSuffix and props.fileNameSuffix~=nil then
								curFileName=string.format('%s%s', curFileName, props.fileNameSuffix)
							end
						end
						return curFileName
				   end
				   return LrBinding.kUnsupportedDirection
				end 

		},
		immediate = true,
		
	--	enabled = LrView.bind {
	--		key = "outputFileNameOption", 
	--		transform = function(value, fromTable)
	--		return value == '10' end
	--	},
		
		enabled = LrView.bind {
			keys = { 'outputFileNameOption', 'waitForPhotomatix' },
			operation = function( binder, values, fromTable )
				if fromTable then
					return values.waitForPhotomatix and values.outputFileNameOption == '10' 
			   end
			end 
		},

	}
	
	
	
	local singleFileSettings = f:column {
		bind_to_object = props,
		spacing = f:dialog_spacing(),
		
		f:row {
			f:static_text {
				title = LOC "$$$/Photomatix/Export/SingleFile/Text1=You are about to export a single file to Photomatix Pro.",
				alignment = 'left',
			},
		},
		f:row {
			f:static_text {
				title = LOC "$$$/Photomatix/Export/SingleFile/Text2=(If you wish to create an HDR image or to fuse^nexposures, then cancel and select bracketed photos^nfor the export instead of a single photo.)",
				alignment = 'left',
			},
		},
		f:group_box {
			title = LOC "$$$/Photomatix/Settings/SingleFile/Title=Processing of exported file",
			show_title=false,
			fill_horizontal=1,
			font = "<system>",
		f:row {	
			f:checkbox {
				title = LOC "$$$/Photomatix/Settings/Reimport=Automatically re-import into Lightroom library",
				tooltip=LOC "$$$/Photomatix/Settings/Reimport/TooltipSingle=When checked, the tone mapped image will be automatically saved and added to your Lightroom library.",
				value = LrView.bind ("waitForPhotomatix"),
				enabled=isLr2,
			},
		},
		f:row {	
			f:static_text {
				title = LOC "$$$/Photomatix/Settings/FileName=File name:",
				enabled = LrView.bind("waitForPhotomatix"),
				alignment = 'right',
			},			
			f:edit_field { 
				value = LrView.bind ("outputName"), 
				enabled = LrView.bind("waitForPhotomatix"),
				fill_horizontal=1,
			},
		},
		
		f:row {	
			f:static_text {
				title = LOC "$$$/Photomatix/Settings/OutputFormat=Output Format:",
				enabled = LrView.bind("waitForPhotomatix"),
				alignment = 'right',
				place_horizontal=0.4
			},			
			f:popup_menu {
				tooltip=LOC "$$$/Photomatix/Settings/OutputFormat/Tooltip=Format for saving the resulting tone mapped or fused image.",
				value = LrView.bind ("outputFormat"),
				items = {
				{ title = "JPEG", value = "jpg" },
				{ title = "TIFF 8-bit", value = "tif8" },
				{ title = "TIFF 16-bit", value = "tif16" },
				},
				fill_horizontal=0.4,
				enabled = LrView.bind("waitForPhotomatix"),
			},
		},
		
		
		f:row {	
			margin_left = LeftMarginSavePanel,
			f:checkbox {
				title = LOC "$$$/Photomatix/Settings/Stack/Single=Stack with selected photo",
				value = LrView.bind ("stackWith"), 
				enabled = LrView.bind("waitForPhotomatix"),
---				alignment = 'left',
---				place_horizontal=0.15,
			},			
		},

		
		
		},
	}


	local multipleFilesSettings = f:column {
		bind_to_object = props,
		spacing = f:dialog_spacing(),
		
		f:row {
			f:static_text {
				title = LOC ("$$$/Photomatix/Settings/Heading=You are about to export ^1 files to Photomatix Pro.  Please set the ^noptions to process the files.",cntPhotos),
				---width = LrView.share "label_width",
				warps=true,
				alignment = 'left',
			},
		},

		f:group_box {
--			title = LOC "$$$/Photomatix/Settings/MultipleFiles/Title=Processing of exported files",
			title = LOC "$$$/Photomatix/Settings/MutipleFiles/Title=Pre-processing Options",
			show_title=true,
			fill_horizontal=1,
			font = "<system>",

		f:row {	
			spacing = f:control_spacing() / 2,
			f:column {
				f:checkbox {
					title = LOC "$$$/Photomatix/Settings/Align/Checkbox=Align images                      ",
					tooltip=LOC "$$$/Photomatix/Settings/Align/Tooltip=Corrects misalignment problems when the camera moves slightly between the bracketed frames.  Always check this option when your bracketed photos are taken hand-held, but do not check it if they are stitched panoramas or derived from a single Raw file.",
					value = LrView.bind ("chkAlign"),
					checked_value = true,
					unchecked_value = false,
				},
			},
			f:column {
				f:checkbox {
					title = LOC "$$$/Photomatix/Settings/Crop/Checkbox=Crop aligned result",
					tooltip=LOC "$$$/Photomatix/Settings/Crop/Tooltip=Checking this option removes the unneeded borders resulting from the alignment adjustments.  Unchecking it disables this, so that the resulting image has exactly the same width and height as the source images.",
					value = LrView.bind ("chkCrop"),
					enabled = LrView.bind("chkAlign"),
					checked_value = true,
					unchecked_value = false,
				},
			},
		},

		f:row {	
			f:column {
				spacing = f:control_spacing() *2/3,
				margin_left = 15,
	--			margin_bottom = f:control_spacing() / 2,
				f:radio_button {
					title =LOC "$$$/Photomatix/Settings/AlignMethod1=by correcting horizontal and vertical shifts",
					tooltip=LOC "$$$/Photomatix/Settings/AlignMethod1/Tooltip=This alignment method is fast, but only corrects for translation movements. Recommended for images shot on a tripod.",
					value = LrView.bind ("alignType"),
					checked_value = '1',
					enabled = LrView.bind("chkAlign"),
				},
				f:row {	
				f:column {
					f:radio_button {
						title =LOC "$$$/Photomatix/Settings/AlignMethod2=by matching features",
						tooltip=LOC "$$$/Photomatix/Settings/AlignMethod2/Tooltip=This alignment method corrects for rotation, translation and scaling differences, as well as perspective distortion if included.",
						value = LrView.bind ("alignType"),
						checked_value = '2',
						enabled = LrView.bind("chkAlign"),
					},
				},
				f:column {
					f:checkbox {
						title = LOC "$$$/Photomatix/Settings/PerspectiveCorrection/Checkbox=include perspective correction",
						tooltip=LOC "$$$/Photomatix/Settings/PerspectiveCorrection/Tooltip=When checked, requests that the alignment by matching features corrects for perspective distortion in addition to correcting for translation, rotation and scaling differences.",
						value = LrView.bind ("chkPerspective"),
						checked_value = true,
						unchecked_value = false,
						enabled = LrView.bind {
							keys = { 'chkAlign', 'alignType' },
							operation = function( binder, values, fromTable )
							   if fromTable then
							      return values.chkAlign and values.alignType == '2'
							   end
							   return LrBinding.kUnsupportedDirection
							end }
					},
				},
				},
			},				
		},


		f:row {	
			spacing = f:control_spacing() / 3,

			f:checkbox {
				title = LOC "$$$/Photomatix/Settings/Deghost=Remove ghosts",
				tooltip=LOC "$$$/Photomatix/Settings/Deghost/Tooltip=Only check this option if your scene includes elements that moved between the bracketed shots. Otherwise, leave it unchecked, as removing ghosts lowers the quality of the merged image.",
				value = LrView.bind ("chkGhosting"),
				checked_value = true,
				unchecked_value = false,
			},
		},
		f:row {	
			f:column {
				spacing = f:control_spacing() *2/3,
				margin_left = 15,
				f:row {	
				f:radio_button {
					title = LOC "$$$/Photomatix/Settings/Deghost/SemiManual=with selective deghosting tool",
					tooltip=LOC "$$$/Photomatix/Settings/Deghost/SemiManual/Tooltip=Select ghosted regions and choose the exposure used to remove the ghosting in each region.",
					value = LrView.bind ("ghostingType"),
					checked_value = '1',
					enabled = LrView.bind("chkGhosting"),
				},
				},
				f:row {	
				f:column {
					f:radio_button {
						title =LOC "$$$/Photomatix/Settings/Deghost/Automatic=automatically",
						tooltip=LOC "$$$/Photomatix/Settings/Deghost/Automatic/Tooltip=Useful when the ghosts are diffused (e.g. sea waves, bushes on a windy day). Otherwise, it is better to use the Selective Deghosting tool.",
						value = LrView.bind ("ghostingType"),
						checked_value = '2',
						enabled = LrView.bind("chkGhosting"),
					},
				},

				f:column {
					spacing = f:control_spacing(),
					f:static_text {
						title = LOC "$$$/Photomatix/Settings/Detection=          Detection:",
						alignment = 'right',
						enabled = LrView.bind {
							keys = { 'chkGhosting', 'ghostingType' },
							operation = function( binder, values, fromTable )
							   if fromTable then
							      return values.chkGhosting and values.ghostingType == '2'
							   end
							   return LrBinding.kUnsupportedDirection
							end }
					},			
				},
				f:column {
					f:popup_menu {
						tooltip=LOC "$$$/Photomatix/Settings/Deghost/Automatic/Detection=Criteria for ghosting detection.",
						value = LrView.bind ("ghostingDetection"),
						items = {
						{ title = LOC "$$$/Photomatix/Settings/Deghost/Automatic/DetectionNormal=Normal", value = "normal" },
						{ title = LOC "$$$/Photomatix/Settings/Deghost/Automatic/DetectionHigh=High", value = "high" },
						},
						fill_horizontal=0.4,
						--enabled = LrView.bind("chkGhosting"),
						enabled = LrView.bind {
							keys = { 'chkGhosting', 'ghostingType' },
							operation = function( binder, values, fromTable )
							   if fromTable then
							      return values.chkGhosting and values.ghostingType == '2'
							   end
							   return LrBinding.kUnsupportedDirection
							end }
					},
				},
				},
			},
		},

		f:row {	
			spacing = f:control_spacing() / 2,
			f:column {			
				f:checkbox {
					title = LOC "$$$/Photomatix/Settings/NR=Reduce noise",
					tooltip=LOC "$$$/Photomatix/Settings/NR/Tooltip=High quality noise reduction but significantly increases processing times. It is better to disable Lightroom Noise Reduction when you check this option",
					value = LrView.bind ("chkReduceNoise"),
					checked_value = true,
					unchecked_value = false,
				},
			},
			f:column {			
				f:popup_menu {
					value = LrView.bind ("nrWhat"),
					items = {
						{ title = LOC "$$$/Photomatix/Settings/NR/UnderOnly=Underexposed image(s) only", value = "0" },
						{ title = LOC "$$$/Photomatix/Settings/NR/NormalUnder=Normal exposure & underexposed", value = "1" },
						{ title = LOC "$$$/Photomatix/Settings/NR/All=All source images", value = "2" },
					},
					fill_horizontal=0.4,
					enabled = LrView.bind("chkReduceNoise"),
				},
			},
		},

		f:row {	
			spacing = f:control_spacing() / 2,
			f:checkbox {
				title = LOC "$$$/Photomatix/Settings/ReduceCA=Reduce chromatic aberrations",
				tooltip=LOC "$$$/Photomatix/Settings/ReduceCA/Tooltip=Attempts to correct for color fringing due to chromatic aberrations of the lens. May not be needed when using Lightroom version 3 and higher. Note that checking this option increases processing times.",
				value = LrView.bind ("chkReduceCA"),
				checked_value = true,
				unchecked_value = false,
			},

		},

		f:row {	
			spacing = f:control_spacing() / 2,
			f:checkbox {
				title = LOC "$$$/Photomatix/Settings/ShowHDR=Show intermediary 32-bit HDR image",
				tooltip=LOC "$$$/Photomatix/Settings/ShowHDR/Tooltip=Check this option if you are interested in saving the 32-bit HDR file before tone mapping it",
				value = LrView.bind ("chkShowHDR"),
				checked_value = true,
				unchecked_value = false,
			},

		},	

		f:row {					
			spacing = f:control_spacing(),
		},
		
		},
		
		f:group_box {
			title = titleBox2,
			fill_horizontal=1,
			show_title=true,
			font = "<system>",
		f:row {	
			f:checkbox {
				title = LOC "$$$/Photomatix/Settings/Reimport=Automatically re-import into Lightroom library",
				tooltip= LOC "$$$/Photomatix/Settings/Reimport/TooltipMultiple=When checked, the tone mapped or fused image will be automatically saved and added to your Lightroom library.",
				value = LrView.bind ("waitForPhotomatix"),
				enabled=isLr2,
			},
		},

--[[
		f:row {	
			f:checkbox {
				title = LOC "$$$/Photomatix/Settings/Stack/Multiple=Stack with first selected photo",
				value = LrView.bind ("stackWith"), 
				enabled = LrView.bind("waitForPhotomatix"),
				alignment = 'left',
				place_horizontal=0.15,
			},			
		},
		
		
		
		
		f:row {	
			spacing = f:control_spacing(),
			f:static_text {
				title = LOC "$$$/Photomatix/Settings/FileName=File name:",
				enabled = LrView.bind("waitForPhotomatix"),
				alignment = 'right',
			},			
			f:edit_field { 
				value = LrView.bind ("outputName"), 
				enabled = LrView.bind("waitForPhotomatix"),
				fill_horizontal=1,
			},
		}, 
--]]		
	
		f:row {	
			f:column {		
				f:static_text {
					title = LOC "$$$/Photomatix/Settings/FileName=File Name:",
					width=LeftMarginSavePanel-5,
					alignment = 'right',
					enabled = LrView.bind("waitForPhotomatix"),
				},			
			},
			f:column {			
				f:popup_menu {
					value = LrView.bind ("outputFileNameOption"),
					items = {
						{ title = LOC "$$$/Photomatix/Settings/OutputFileName/CombinedFileName=Combined file names", value = "0" },
						{ title = LOC "$$$/Photomatix/Settings/OutputFileName/FileNameFirstPhoto=File name of first photo                       ", value = "1" },
						{ separator = true}, 
						{ title = LOC "$$$/Photomatix/Settings/OutputFileName/CustomFileName=Custom file name...", value = "10" },
					},
					enabled = LrView.bind("waitForPhotomatix"),
				},
			},			
		},		
		f:row {	
			margin_left = LeftMarginSavePanel,
			outputFileNameEditField,
		},	

		f:row {	
			f:column {
				f:static_text {
					title = LOC "$$$/NotToBeEditedByTranslators/SpaceForFitting/LeftMarginAddSuffix=        ",
				},			
			},	
					
			f:column {
				f:checkbox {
					title = LOC "$$$/Photomatix/Settings/OutputFileName/SuffixLabel=Add suffix:",
					value = LrView.bind ("chkAddSuffix"),
					checked_value = true,
					unchecked_value = false,
					enabled = LrView.bind {
						keys = { 'outputFileNameOption', 'waitForPhotomatix' },
						operation = function( binder, values, fromTable )
							if fromTable then
								return values.waitForPhotomatix and values.outputFileNameOption ~= '10' 
						   end
						end 
					},
				},
			},

			f:column {
				f:edit_field { 
					width_in_chars = 15, 
					value = LrView.bind ("fileNameSuffix"), 
					enabled = LrView.bind {
						keys = { 'outputFileNameOption', 'chkAddSuffix' },
						operation = function( binder, values, fromTable )
							local curFileName=''
							if fromTable then
								return values.chkAddSuffix and values.outputFileNameOption ~= '10' 
						   end
						   return LrBinding.kUnsupportedDirection
						end 
					}	

				},
			},
		},
						
		
		
		f:row {	
			f:static_text {
				title = LOC "$$$/Photomatix/Settings/OutputFormat=Output Format:",
				width=LeftMarginSavePanel-5,
				alignment = 'right',
				enabled = LrView.bind("waitForPhotomatix"),
			},			
			f:popup_menu {
				tooltip=LOC "$$$/Photomatix/Settings/OutputFormat/Tooltip=Format for saving the resulting tone mapped or fused image.",
				value = LrView.bind ("outputFormat"),
				items = {
				{ title = "JPEG", value = "jpg" },
				{ title = "TIFF 8-bit", value = "tif8" },
				{ title = "TIFF 16-bit", value = "tif16" },
				},
				enabled = LrView.bind("waitForPhotomatix"),
			},
		},
		
		f:row {	
			margin_left = LeftMarginSavePanel,
			f:checkbox {
				title = LOC "$$$/Photomatix/Settings/Stack/Single=Stack with selected photo",
				value = LrView.bind ("stackWith"), 
				enabled = LrView.bind("waitForPhotomatix"),
			},			
		},

		
		
		},
	}

	local settingsContents=multipleFilesSettings
	if cntPhotos==1 then
		settingsContents=singleFileSettings
	end
	local result = LrDialogs.presentModalDialog(  {
		title = LOC "$$$/Photomatix/Settings/Title=Settings for processing exported files",
		contents = settingsContents,
		actionVerb = LOC "$$$/Photomatix/General/Export=Export",
	}
	)


		local outputFileName=props.combinedFileName
		
		if cntPhotos==1 then
			outputFileName=props.outputName
		else 
		
			if props.outputFileNameOption == '10' then
				outputFileName=outputFileNameEditField.value
				if outputFileName == '' then
					outputFileName=props.combinedFileName
				end
			else
				if props.outputFileNameOption == '1' then
					outputFileName=props.firstFileName
				end
				if props.chkAddSuffix and props.fileNameSuffix~=nil then
					outputFileName=string.format('%s%s', outputFileName, props.fileNameSuffix)
				end
			end
		end

	if (result=='ok') then
		prefs.processType='ToneMap'
		prefs.chkAlign=props.chkAlign
		prefs.chkCrop=props.chkCrop
		prefs.alignType=props.alignType
		prefs.chkPerspective=props.chkPerspective
		prefs.chkGhosting=props.chkGhosting
		prefs.ghostingType=props.ghostingType
		prefs.ghostingDetection=props.ghostingDetection
		prefs.chkReduceNoise=props.chkReduceNoise
		prefs.nrWhat=props.nrWhat
		prefs.chkReduceCA=props.chkReduceCA
		prefs.chkShowHDR=props.chkShowHDR
		prefs.waitForPhotomatix=props.waitForPhotomatix 
		prefs.outputFormat=props.outputFormat
		prefs.stackWith=props.stackWith

--		local outputExt=string.sub(props.outputFormat, 1, 3)
--		prefs.outputPath=LrPathUtils.child(folderPath, LrPathUtils.addExtension(props.outputName, outputExt))
--		prefs.outputPath=LrFileUtils.chooseUniqueFileName(prefs.outputPath)
--		PhotomatixSettings.outputToLog(string.format('prefs.outputPath:  %s',prefs.outputPath))

		prefs.outputFileNameOption=props.outputFileNameOption
		prefs.chkAddSuffix=props.chkAddSuffix
		prefs.fileNameSuffix=props.fileNameSuffix
			
		local outputExt=string.sub(props.outputFormat, 1, 3)		
		prefs.outputPath=LrPathUtils.child(folderPath, LrPathUtils.addExtension(outputFileName, outputExt))
		prefs.outputPath=LrFileUtils.chooseUniqueFileName(prefs.outputPath)

	else
		prefs.processType='none'
	end	
	
end )

end
